/**
    Copyright 2014-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.

    Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with the License. A copy of the License is located at

        http://aws.amazon.com/apache2.0/

    or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
*/

/**
 * This simple sample has no external dependencies or session management, and shows the most basic
 * example of how to create a Lambda function for handling Alexa Skill requests.
 *
 * Examples:
 * One-shot model:
 *  User: "Alexa, ask Space Geek for a space fact"
 *  Alexa: "Here's your space fact: ..."
 */

/**
 * App ID for the skill
 */
var APP_ID =undefined; //OPTIONAL: replace with "amzn1.echo-sdk-ams.app.[your-unique-value-here]";

/**
 * Array containing space facts.
 */
var FACTS = [
"Carbohydrates, protein, fat, and alcohol have 4, 4, 9, and 7 calories per gram respectively.",
"You need to burn about 3500 calories to lose 1 pound of fat.",
"Insulin and growth hormone have an inverse relationship. You must keep insulin under control if you want growth hormone to do its job of mobilizing fat.",
"The average person can store 500 grams of glycogen.",
"Only fat and protein are essential macronutrients – carbohydrates aren’t (but that doesn’t mean you shouldn’t eat them).",
"Muscle glycogen is about 3 parts water to 1 part glucose. This can add water weight at the beginning of a strength training program.",
"You burn more calories during the 23 hours you don’t exercise than the 1 hour you do.",
"You don’t need to do cardio to lose weight. You only need a calorie deficit. But that doesn’t mean it isn’t a useful tool.",
"The fat burning zone does not burn more total fat calories – only a higher percentage of calories from fat. Total calories burned is what matters.",
"You’re never too old to do squats.",
"Weight loss is not a physical challenge – it’s a mental one.",
"The scale cannot measure your body fat. However, this body fat caliper can. Use it.",
"You can eat anything you want and still lose weight – but weight doesn’t always equal fat.",
"You can’t target fat loss – fat loss is systemic.",
"Muscle does not weigh more than fat – it’s just denser than it.",
"Zero grams of fat on a label doesn’t always mean there’s no fat in the food product. Always check the ingredients.",
"Whole grain bread can contain many artificial chemicals – pick one that uses only whole food ingredients.",
"Eating healthy is not more expensive than a junk food diet, especially once you consider health care costs down the road.",
"You can’t calculate body fat percentage from height and weight alone – you need to physically measure it.",
"You can get glucose from both protein and glycerol – not just carbohydrates.",
"Just because a box says “whole grain” on it, it doesn’t make it healthy.",
"You should never attempt weight loss at the expense of your health.",
"Trying to be perfect with your diet sets you up for failure. Strive to make progress by continually creating healthy eating habits.",
"Workout times and negative side effects are positively correlated. The quality of your workouts is more important than the quantity.",
"Gym membership prices are usually negotiable. Don’t be afraid to ask.",
"Cooking your food can both lower some nutrient content, and make some more bio-available.",
"There’s a high correlation between the fitness level of the people close to you, and your own physical fitness.",
"It’s harder to put on 10 pounds of muscle than it is to lose 10 pounds of fat.",
"Once an adult, fat cells can be created, but they cannot be lost – only shrunken. But that doesn’t mean they can’t shrink to close to nothing.",
"Eating at night does not make you fat – overeating does.",
"You don’t need to do curls to get good biceps. Heavy rowing movements are excellent arm builders.",
"Being skinny does not automatically mean you have a low body fat. Body composition is what matters most.",
"The perimeter of the grocery store is where 90% of the healthy food is.",
"If bad food is in the house, you’ll be more likely to eat it.",
"Thyroid hormone output and exercise intensity are positively correlated.",
"Healthy levels of testosterone are good for both men and women.",
"You don’t need a gym membership to strength train. Your body weight is all the resistance you need.",
"90% of people underestimate how many calories they need to eat to lose weight. Use my calorie calculator to determine the correct calorie intake for fat loss.",
"Workout intensity is positively correlated with the degree of EPOC – the afterburn effect. Boost your intensity if you want to burn more fat.",
"There are 3 types of skeletal muscle fibers – type I, type II-A, and type II-B.",
"80% of people who begin an exercise program will quit. About the same goes for people starting a diet.",
"The body has 3 energy systems – ATP-PC, anaerobic glycolysis, and aerobic.",
"Strength gains come from muscle hypertrophy and improved muscle fiber recruitment. Include a variety of rep ranges in your workouts.",
"Dehydrating a muscle by 3% can cause a 10% loss of strength. Drink plenty of water throughout the day.",
"The thermic effect of food (TEF) is highest for protein. Up to 30% of its calories are used for digestion and assimilation.",
"Lactic acid is not the cause of delayed-onset muscle soreness (DOMS). Lactic acid returns to normal levels within 60 minutes of finishing exercise.",
"The more muscle mass you have, the more calories you burn at rest. Muscle tissue eats fat at all hours of the day.",
"Direct abdominal exercises are not necessary to get good abs. Abs are used as stabilizers when you do squats, deadlifts, and many other exercises. Only a good diet will make them visible.",
"You can lose weight and still gain muscle; likewise, you can also gain weight while still losing fat.",
"Consistency and patience are key to long term successful weight loss."
];

/**
 * The AlexaSkill prototype and helper functions
 */
var AlexaSkill = require('./AlexaSkill');

/**
 * SpaceGeek is a child of AlexaSkill.
 * To read more about inheritance in JavaScript, see the link below.
 *
 * @see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Introduction_to_Object-Oriented_JavaScript#Inheritance
 */
var Fact = function () {
    AlexaSkill.call(this, APP_ID);
};

// Extend AlexaSkill
Fact.prototype = Object.create(AlexaSkill.prototype);
Fact.prototype.constructor = Fact;

Fact.prototype.eventHandlers.onSessionStarted = function (sessionStartedRequest, session) {
    //console.log("onSessionStarted requestId: " + sessionStartedRequest.requestId + ", sessionId: " + session.sessionId);
    // any initialization logic goes here
};

Fact.prototype.eventHandlers.onLaunch = function (launchRequest, session, response) {
    //console.log("onLaunch requestId: " + launchRequest.requestId + ", sessionId: " + session.sessionId);
    handleNewFactRequest(response);
};

/**
 * Overridden to show that a subclass can override this function to teardown session state.
 */
Fact.prototype.eventHandlers.onSessionEnded = function (sessionEndedRequest, session) {
    //console.log("onSessionEnded requestId: " + sessionEndedRequest.requestId + ", sessionId: " + session.sessionId);
    // any cleanup logic goes here
};

Fact.prototype.intentHandlers = {
    "GetNewFactIntent": function (intent, session, response) {
        handleNewFactRequest(response);
    },

    "AMAZON.HelpIntent": function (intent, session, response) {
        response.ask("You can say tell me an Fitness fact, or, you can say exit... What can I help you with?", "What can I help you with?");
    },

    "AMAZON.StopIntent": function (intent, session, response) {
        var speechOutput = "Goodbye";
        response.tell(speechOutput);
    },

    "AMAZON.CancelIntent": function (intent, session, response) {
        var speechOutput = "Goodbye";
        response.tell(speechOutput);
    }
};

/**
 * Gets a random new fact from the list and returns to the user.
 */
function handleNewFactRequest(response) {
    // Get a random space fact from the space facts list
    var factIndex = Math.floor(Math.random() * FACTS.length);
    var randomFact = FACTS[factIndex];

    // Create speech output
    var speechOutput = "" + randomFact;
    var cardTitle = "Your Fitness fact";
    response.tellWithCard(speechOutput, cardTitle, speechOutput);
}

// Create the handler that responds to the Alexa Request.
exports.handler = function (event, context) {
    // Create an instance of the SpaceGeek skill.
    var fact = new Fact();
    fact.execute(event, context);
};

